@@ -1,115 +1,70 @@
 /*
- * The Apache Software License, Version 1.1
+ * Copyright 1999-2004 The Apache Software Foundation.
  *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * Copyright (c) 1999 The Apache Software Foundation.  All rights 
- * reserved.
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:  
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xalan" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written 
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
-#include <iostream>
-#include <strstream>
-#include <stdio.h>
-#include <direct.h>
+// Base header file.  Must be first.
+#include <xalanc/Include/PlatformDefinitions.hpp>
 
 
+
+#include <cstdio>
+
+#if defined(XALAN_CLASSIC_IOSTREAMS)
+#include <iostream.h>
+#else
+#include <iostream>
+#endif
+
 // This is here for memory leak testing.
 #if !defined(NDEBUG) && defined(_MSC_VER)
 #include <crtdbg.h>
 #endif
 
-#include <vector>
 
-#include <util/PlatformUtils.hpp>
+#include <xercesc/util/PlatformUtils.hpp>
 
-#include <PlatformSupport/DOMStringHelper.hpp>
-#include <PlatformSupport/XalanFileOutputStream.hpp>
-#include <PlatformSupport/XalanOutputStreamPrintWriter.hpp>
+#include <xalanc/PlatformSupport/DOMStringHelper.hpp>
+#include <xalanc/PlatformSupport/XalanFileOutputStream.hpp>
+#include <xalanc/PlatformSupport/XalanOutputStreamPrintWriter.hpp>
 
-#include <XalanSourceTree/XalanSourceTreeDOMSupport.hpp>
-#include <XalanSourceTree/XalanSourceTreeParserLiaison.hpp>
+#include <xalanc/XalanSourceTree/XalanSourceTreeDOMSupport.hpp>
+#include <xalanc/XalanSourceTree/XalanSourceTreeParserLiaison.hpp>
 
-#include <XPath/XObjectFactoryDefault.hpp>
-#include <XPath/XPathFactoryDefault.hpp>
+#include <xalanc/XPath/XObjectFactoryDefault.hpp>
+#include <xalanc/XPath/XPathFactoryDefault.hpp>
 
-#include <XSLT/StylesheetConstructionContextDefault.hpp>
-#include <XSLT/StylesheetExecutionContextDefault.hpp>
-#include <XSLT/StylesheetRoot.hpp>
-#include <XSLT/XSLTEngineImpl.hpp>
-#include <XSLT/XSLTInit.hpp>
-#include <XSLT/XSLTInputSource.hpp>
-#include <XSLT/XSLTProcessorEnvSupportDefault.hpp>
-#include <XSLT/XSLTResultTarget.hpp>  
+#include <xalanc/XSLT/StylesheetConstructionContextDefault.hpp>
+#include <xalanc/XSLT/StylesheetExecutionContextDefault.hpp>
+#include <xalanc/XSLT/StylesheetRoot.hpp>
+#include <xalanc/XSLT/XSLTEngineImpl.hpp>
+#include <xalanc/XSLT/XSLTInit.hpp>
+#include <xalanc/XSLT/XSLTInputSource.hpp>
+#include <xalanc/XSLT/XSLTProcessorEnvSupportDefault.hpp>
+#include <xalanc/XSLT/XSLTResultTarget.hpp>  
 
-#include <XMLFileReporter.hpp>
-#include <FileUtility.hpp>
-#include <HarnessInit.hpp>
+#include <Harness/XMLFileReporter.hpp>
+#include <Harness/FileUtility.hpp>
+#include <Harness/HarnessInit.hpp>
 
-#if !defined(XALAN_NO_NAMESPACES)
-	using std::cerr;
-	using std::cout;
-	using std::cin;
-	using std::endl;
-	using std::ifstream;
-	using std::ios_base;
-	using std::ostrstream;
-	using std::string;
-#endif
+
+
+XALAN_USING_STD(cerr)
+XALAN_USING_STD(cout)
+XALAN_USING_STD(endl)
 
 
-#if defined(XALAN_NO_NAMESPACES)
-	typedef map<XalanDOMString, XalanDOMString, less<XalanDOMString> >	Hashtable;
-#else
-	typedef std::map<XalanDOMString, XalanDOMString>	Hashtable;
-#endif
 
 const char* const 	excludeStylesheets[] =
 {
@@ -118,27 +73,35 @@ const char* const 	excludeStylesheets[] =
 };
 
 
-inline bool
-checkForExclusion(XalanDOMString currentFile)
-{
 
-		for (int i=0; excludeStylesheets[i] != 0; i++)
-			{	
-				if (equals(currentFile, XalanDOMString(excludeStylesheets[i])))
-					{
-						return true;
-					}
-			}
-		return false;
+// Just hoist everything...
+XALAN_CPP_NAMESPACE_USE
+
+
+
+inline bool
+checkForExclusion(const XalanDOMString&		currentFile)
+{
+	for (int i=0; excludeStylesheets[i] != 0; i++)
+	{	
+		if (equals(currentFile, XalanDOMString(excludeStylesheets[i])))
+		{
+			return true;
+		}
+	}
+
+	return false;
 }
 
+
+
 inline StylesheetRoot*
 processStylesheet(
 			const XalanDOMString&			theFileName,
 			XSLTProcessor&					theProcessor,
 			StylesheetConstructionContext&	theConstructionContext)
 {
-	const XSLTInputSource	theInputSource(c_wstr(theFileName));
+	const XSLTInputSource	theInputSource(theFileName);
 
 	return theProcessor.processStylesheet(theInputSource, theConstructionContext);
 }
@@ -150,7 +113,7 @@ parseSourceDocument(
 			const XalanDOMString&	theFileName,
 			XSLTProcessor&			theProcessor)
 {
-	const XSLTInputSource	theInputSource(c_wstr(theFileName));
+	const XSLTInputSource	theInputSource(theFileName);
 
 	return theProcessor.getSourceTreeFromInput(theInputSource);
 }
@@ -166,6 +129,7 @@ calculateElapsedTime(
 }
 
 
+
 inline double
 calculateAvgTime(
 			clock_t		accTime,
@@ -176,6 +140,8 @@ calculateAvgTime(
 	return double(accTime) / theIterationCount;
 }
 
+
+
 inline double
 calculateAverageElapsedTime( 
 			clock_t			theStartTime,
@@ -187,45 +153,56 @@ calculateAverageElapsedTime(
 	return calculateElapsedTime(theStartTime, theEndTime) / theIterationCount;
 }
 
+
+
 inline clock_t
-transformWUnparsedSource(const XalanDOMString&	theFileName,
-				 XSLTProcessor&			theProcessor,
-				 const StylesheetRoot*	theStylesheetRoot,
-				 XSLTResultTarget&	theResults,
-				 StylesheetExecutionContextDefault&  theExecutionContext)
+transformWUnparsedSource(
+			const XalanDOMString&				theFileName,
+			XSLTProcessor&						theProcessor,
+			const StylesheetRoot*				theStylesheetRoot,
+			XSLTResultTarget&					theResults,
+			StylesheetExecutionContextDefault&  theExecutionContext)
 {
-	const XSLTInputSource	csSourceXML(c_wstr(theFileName));	// Creates source document
+	const XSLTInputSource	csSourceXML(c_wstr(theFileName));
+
 	theProcessor.setStylesheetRoot(theStylesheetRoot);
 
 	const clock_t startTime = clock();
-	theProcessor.process(csSourceXML, theResults, theExecutionContext);
-	const clock_t endTime = clock();
 
-	return endTime - startTime;
+	theProcessor.process(csSourceXML, theResults, theExecutionContext);
+
+	return clock() - startTime;
 
 }
 
+
+
 inline clock_t
-transformWParsedSource(XalanNode*		theParsedSource,
-				 XSLTProcessor&			theProcessor,
-				 const StylesheetRoot*	theStylesheetRoot,
-				 XSLTResultTarget&		theResults,
-				 StylesheetExecutionContextDefault&  theExecutionContext)
+transformWParsedSource(
+			XalanNode*							theParsedSource,
+			XSLTProcessor&						theProcessor,
+			const StylesheetRoot*				theStylesheetRoot,
+			XSLTResultTarget&					theResults,
+			StylesheetExecutionContextDefault&	theExecutionContext)
 {
 	// Put the parsed document into an XSLTInputSource, 
 	// and set stylesheet root in the processor
 	const XSLTInputSource	csSourceDocument(theParsedSource);
+
 	theProcessor.setStylesheetRoot(theStylesheetRoot);
 
 	const clock_t startTime = clock();
-	theProcessor.process(csSourceDocument, theResults, theExecutionContext);
-	const clock_t endTime = clock();
-	
-	return endTime - startTime;
 
+	theProcessor.process(csSourceDocument, theResults, theExecutionContext);
+	
+	return clock() - startTime;
 }
+
+
+
 inline long
-eTOeTransform(const XSLTInputSource&		inputSource, 
+eTOeTransform(
+			const XSLTInputSource&			inputSource,
 	        const XSLTInputSource&			stylesheetSource,
 	        XSLTResultTarget&				outputTarget,
 			StylesheetConstructionContext&	constructionContext,
@@ -233,29 +210,33 @@ eTOeTransform(const XSLTInputSource&		inputSource,
 			XSLTProcessor&					theProcessor)
 {
 	const clock_t startTime=clock();
-	theProcessor.process(inputSource, 
-			        	stylesheetSource,
-				    	outputTarget,
-						constructionContext,
-						executionContext);
+
+	theProcessor.process(
+				inputSource, 
+			    stylesheetSource,
+				outputTarget,
+				constructionContext,
+				executionContext);
+
 	const clock_t endTime=clock();
 
 	return endTime - startTime;
 }
 
 
+
 void
-printArgOptions()
+setHelp(FileUtility&	h)
 {
-	cerr << endl
-		 << "Perf dirname [-out -category -i -iter]"
+	h.args.getHelpStream() << endl
+		 << "Perf dir [-out -sub -i -iter]"
 		 << endl
 		 << endl
-		 << "dirname		(base directory for testcases)"
+		 << "dir		(base directory for testcases)"
 		 << endl
-		 << "-out dirname	(base directory for output)"
+		 << "-out dir	(base directory for output)"
 		 << endl
-		 << "-category dirname (run files only from a specific directory)"
+		 << "-sub dir (run files only from a specific directory)"
 		 << endl
 		 << "-i                (include all testcases)"
 		 << endl
@@ -263,157 +244,41 @@ printArgOptions()
 		 << endl;
 }
 
-bool
-getParams(int argc, 
-		  const char*	argv[],
-		  FileUtility& f,
-		  XalanDOMString& basedir,
-		  XalanDOMString& outdir,
-		  XalanDOMString& category,
-		  bool& skip,
-		  long& iterCount)
-{
-bool fSuccess = true;	// Used to continue argument loop
-bool fSetOut = true;	// Set default output directory
-
-
-	// Insure that required "-base" argument is there.
-	if (argc == 1 || argv[1][0] == '-')
-	{
-		printArgOptions(); 
-		return false;
-	}
-	else
-	{
-		if (f.checkDir(pathSep + XalanDOMString(argv[1])))
-		{
-			assign(basedir, XalanDOMString(argv[1]));
-			insert(basedir, 0, pathSep);
-		}
-		else
-		{
-			cout << endl << "Given base directory \"" << argv[1] << "\" does not exist" << endl;
-			printArgOptions();
-			return false;
-		}
-	}
-
-	// Get the rest of the arguments in any order.
-	for (int i = 2; i < argc && fSuccess == true; ++i)
-	{
-		if(!stricmp("-out", argv[i]))
-		{
-			++i;
-			if(i < argc && argv[i][0] != '-')
-			{
-				assign(outdir, XalanDOMString(argv[i]));
-				insert(outdir, 0, XalanDOMString("\\"));
-				append(outdir, XalanDOMString("\\"));
-				f.checkAndCreateDir(outdir);
-				fSetOut = false;
-			}
-			else
-			{
-				printArgOptions();
-				fSuccess = false;
-			}
-		}
-		else if(!stricmp("-category", argv[i]))
-		{
-			++i;
-			if(i < argc && argv[i][0] != '-')
-			{
-				assign(category, XalanDOMString(argv[i]));
-			}
-			else
-			{
-				printArgOptions();
-				fSuccess = false;
-			}
-		}
-		else if(!stricmp("-i", argv[i]))
-		{
-			skip = false;
-		}
-		else if(!stricmp("-iter", argv[i]))
-		{
-			++i;
-			
-			// Make sure number is there and is greater then zero
-			if(i < argc && atol(argv[i]) > 0)
-			{
-				iterCount = atol(argv[i]);
-			}
-			else
-			{
-				printArgOptions();
-				fSuccess = false;
-			}
-		}
-		else
-		{
-			printArgOptions();
-			fSuccess = false;
-		}
-
-	} // End of for-loop
-
-	// Do we need to set the default output directory??
-	if (fSetOut)
-	{
-		unsigned int ii = lastIndexOf(basedir,charAt(pathSep,0));
-		outdir = substring(basedir, 0, ii+1);
-		append(outdir,XalanDOMString("PERF-RESULTS\\"));
-		f.checkAndCreateDir(outdir);
-	}
-	
-	// Add the path seperator to the end of the base directory
-	append(basedir,pathSep);
-	return fSuccess;
-}
-
-
 int
 main(
-	 int			argc,
-	 const char*	argv[])
+			int		argc,
+			char*	argv[])
 {
 #if !defined(NDEBUG) && defined(_MSC_VER)
 	_CrtSetDbgFlag(_CrtSetDbgFlag(_CRTDBG_REPORT_FLAG) | _CRTDBG_LEAK_CHECK_DF);
-
 	_CrtSetReportMode(_CRT_WARN, _CRTDBG_MODE_FILE);
 	_CrtSetReportFile(_CRT_WARN, _CRTDBG_FILE_STDERR);
 #endif
 
-	Hashtable runAttrs;		// Attribute list for perfdata element
-	long iterCount = 5;		// Default number of iterations
+
+	const XalanDOMString	processorType(XALAN_STATIC_UCODE_STRING("XalanC"));
 	bool skip = true;		// Default will skip long tests
+	bool setGold = false;
 
-	XalanDOMString  category;	// Test all of base dir by default
-	XalanDOMString  baseDir;	
-	XalanDOMString  outputRoot;	
+	HarnessInit		xmlPlatformUtils;
 
-	FileUtility f;
+	FileUtility		h;
 
-	if (getParams(argc, argv, f, baseDir, outputRoot, category, skip, iterCount) == true)
+	// Set the program help string,  then get the command line parameters.
+	//
+	setHelp(h);
+
+	if (h.getParams(argc, argv, "PERF-RESULTS", setGold) == true)
 	{
 
 		// Generate Unique Run id and processor info
-		const XalanDOMString UniqRunid = f.GenerateUniqRunid();
-		const XalanDOMString processorType(XALAN_STATIC_UCODE_STRING("XalanC"));
-
-		// Defined basic constants for file manipulation and open results file
-		const XalanDOMString  resultFilePrefix(XalanDOMString("cpp"));
-		const XalanDOMString  resultsFile(outputRoot + resultFilePrefix + UniqRunid + XMLSuffix);
+		const XalanDOMString	UniqRunid = h.generateUniqRunid();
+		const XalanDOMString	resultFilePrefix(XalanDOMString("cpp"));
+		const XalanDOMString	resultsFile(h.args.output + resultFilePrefix + UniqRunid + FileUtility::s_xmlSuffix);
 
 		XMLFileReporter	logFile(resultsFile);
-		logFile.logTestFileInit("Performance Testing - Reports performance times for single transform, and average for multiple transforms using compiled stylesheet");
 
-		// Create initial entry in results file that has info somewhat equivlent to what XalanJ
-		// reports in the hashtable entries.
-		runAttrs.insert(Hashtable::value_type(XalanDOMString("UniqRunid"), UniqRunid));
-		logFile.addMetricToAttrs("Iterations",iterCount, runAttrs);
-		logFile.logElement(10, "perfdata", runAttrs, "xxx");
+		logFile.logTestFileInit("Performance Testing - Reports performance times for single transform, and average for multiple transforms using compiled stylesheet");
 
 		try
 		{
@@ -421,60 +286,68 @@ main(
 			// Having xmlplatformutils in it's own class like this means that if there are
 			// exceptions then terminate() is sure to run because it will automatically get
 			// cleaned up when this instance goes out of scope.
-			HarnessInit xmlPlatformUtils;
-
+			bool foundDir = false;	// Flag indicates directory found. Used in conjunction with -sub cmd-line arg.
 			{
 				XSLTInit	theInit;  
 		
+				typedef FileUtility::FileNameVectorType		FileNameVectorType;
+
 				// Get the list of Directories that are below perf and iterate through them
-				const FileNameVectorType dirs = f.getDirectoryNames(baseDir);
+				const FileNameVectorType dirs = h.getDirectoryNames(h.args.base);
+
+				const long 	iterCount = h.args.iters;
 
 				for(FileNameVectorType::size_type	j = 0; j < dirs.size(); j++)
 				{
-					// Run specific category of files from given directory
-					if (length(category) > 0 && !equals(dirs[j], category))
+					// Run specific sub of files from given directory
+					if (length(h.args.sub) > 0 && !equals(dirs[j], h.args.sub))
 					{
 						continue;
 					}
 
-					cout << "Processing files in Directory: " << dirs[j] << endl;
-
 					// Check that output directory is there.
-					const XalanDOMString  theOutputDir = outputRoot + dirs[j];
-					f.checkAndCreateDir(theOutputDir);
+					const XalanDOMString  theOutputDir = h.args.output + dirs[j];
+					h.checkAndCreateDir(theOutputDir);
+
+					logFile.logTestCaseInit(XalanDOMString("Performance Directory: ") + dirs[j] );
+					
+					// Indicate that directory was processed and get test files from the directory
+					foundDir = true;
+					const FileNameVectorType files = h.getTestFileNames(h.args.base, dirs[j], false);
 
-					logFile.logTestCaseInit(XalanDOMString("Performance Directory: ") + dirs[j] ); 
-					const FileNameVectorType files = f.getTestFileNames(baseDir, dirs[j], false);
 					for(FileNameVectorType::size_type i = 0; i < files.size(); i++)
 					{
 						// Define  variables used for timing and reporting ...
 						clock_t startTime, endTime, accmTime, avgEtoe;
 						double timeinMilliseconds, theAverage;
-						Hashtable attrs;
 
-						attrs.insert(Hashtable::value_type(XalanDOMString("idref"), files[i]));
-						attrs.insert(Hashtable::value_type(XalanDOMString("UniqRunid"),UniqRunid));
-						attrs.insert(Hashtable::value_type(XalanDOMString("processor"),processorType));
-						
-						if (skip)
+						typedef XMLFileReporter::Hashtable	Hashtable;
+
+						Hashtable attrs;
+					
+						if (skip && checkForExclusion(files[i]))
 						{
-							if (checkForExclusion(files[i]))
-								continue;
+							continue;
 						}
 
-						const XalanDOMString  theXSLFile= baseDir + dirs[j] + pathSep + files[i];
-						const XalanDOMString  theXMLFile = f.GenerateFileName(theXSLFile,"xml");
+						const XalanDOMString  theXSLFile= h.args.base + dirs[j] + FileUtility::s_pathSep + files[i];
+						const XalanDOMString  theXMLFile = h.generateFileName(theXSLFile,"xml");
 
-						const XalanDOMString  theOutput =  outputRoot + dirs[j] + pathSep + files[i]; 
-						const XalanDOMString  theOutputFile = f.GenerateFileName(theOutput, "out");
+						const XalanDOMString  theOutput =  h.args.output + dirs[j] + FileUtility::s_pathSep + files[i]; 
+						const XalanDOMString  theOutputFile = h.generateFileName(theOutput, "out");
 
 
 						attrs.insert(Hashtable::value_type(XalanDOMString("href"), theXSLFile));
 						// Create the necessary support objects to instantiate a processor.
-						XalanSourceTreeDOMSupport		csDOMSupport;
+
+						XercesDOMSupport				csDOMSupport;
+						XercesParserLiaison				csParserLiaison(csDOMSupport);
+
+						/*XalanSourceTreeDOMSupport		csDOMSupport;
 						XalanSourceTreeParserLiaison	csParserLiaison(csDOMSupport);
 
 						csDOMSupport.setParserLiaison(&csParserLiaison);
+						*/
 
 						XSLTProcessorEnvSupportDefault	csXSLTProcessorEnvSupport;
 						XObjectFactoryDefault			csXObjectFactory;
@@ -499,7 +372,6 @@ main(
 						// stylesheet's factory support objects.
 						StylesheetConstructionContextDefault	csConstructionContext(
 														csProcessor,
-														csXSLTProcessorEnvSupport,
 														ssXPathFactory);
 						cout << endl << files[i] << endl;
 
@@ -541,8 +413,8 @@ main(
 						// other objects created as a result of the execution.
 
 						XSLTResultTarget		theResultTarget(theOutputFile);
-						const XSLTInputSource	xslInputSource(c_wstr(theXSLFile));
-						const XSLTInputSource	xmlInputSource(c_wstr(theXMLFile));
+						const XSLTInputSource	xslInputSource(theXSLFile);
+						const XSLTInputSource	xmlInputSource(theXMLFile);
 
 						StylesheetExecutionContextDefault	psExecutionContext(
 											csProcessor,
@@ -568,11 +440,7 @@ main(
 						logFile.addMetricToAttrs("single",timeinMilliseconds, attrs);
 
 
-
-			
-
 						// Do a total end to end transform with no pre parsing of either xsl or xml files.
-
 						const etoetran = eTOeTransform(xmlInputSource, 
 													xslInputSource,
 													theResultTarget,
@@ -589,8 +457,6 @@ main(
 						// These are done 3 different ways.
 						// FIRST: Parsed XSL Stylesheet and Parsed XML Source.
 
-						// addMetricToAttrs("Iterations",iterCount, attrs);
-
 						accmTime = 0;
 						for(int j = 0; j < iterCount; ++j)
 						{	
@@ -606,7 +472,6 @@ main(
 
 						// Output average transform time to console and result log
 						cout << endl  << "   Avg: " << theAverage << " for " << iterCount << " iter's w/Parsed files" << endl;
-
 						logFile.addMetricToAttrs("avgparsedxml",theAverage, attrs);
 
 						// SECOND: Parsed Stylesheet and UnParsed XML Source.
@@ -650,35 +515,34 @@ main(
 
 						// Output average transform time to console and result log
 						cout << "   Avg: " << theAverage << " for " << iterCount << " iter's of eToe" << endl;
-
 						logFile.addMetricToAttrs("avgetoe",theAverage, attrs);
-
-
-						logFile.logElement(10, "perf", attrs, "xxx");
-					}//for files
+						logFile.logElementWAttrs(10, "perf", attrs, "xxx");
+					}
 
 					logFile.logTestCaseClose(XalanDOMString("Performance Directory: ") + dirs[j], XalanDOMString("Done") );
-				}//for dirs
+				}
 
-			}//xsltinit
+			}
 
-		logFile.logTestFileClose("Performance", "Done");
-		logFile.close();
-
-		}//try
+			// Check to see if -sub cmd-line directory was processed correctly.
+			if (!foundDir)
+			{
+				cout << "Specified test directory: \"" << c_str(TranscodeToLocalCodePage(h.args.sub)) << "\" not found" << endl;
+			}
 
+			h.reportPassFail(logFile, UniqRunid);
+			logFile.logTestFileClose("Performance", "Done");
+			logFile.close();
+		}
 		catch(const XalanFileOutputStream::XalanFileOutputStreamOpenException& ex)
 		{
 			cerr << ex.getMessage() << endl << endl;
 		}
-
 		catch(...)
 		{
 			cerr << "Exception caught!!!" << endl  << endl;
 		}
-		
-
-	} //if getParams
+	}
 
 	return 0;
 }
